==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Naloži/Shrani</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Samodejno shrani</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Samodejno shranjevanje v:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Samodejno shranjevanje spodletelo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Samodejno shranjevanje zaključeno.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Najdena je bila samodejno shanjena varnostna kopija neznanege risanja. Jo želite obnovit?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>Najdenih je bil %1 samodejno shanjenih varnostnih kopij neznanih risanj. Jih želite obnovit?</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Recover Files?</source>
        <translation>Obnovim datoteke?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnovljeno</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnovim datoteko?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Najdena je bila samodejno shanjena varnostna kopija &apos;%1&apos;. Jo želite obnovit?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Ni mogoče preimenovat:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Premaknjena samodejna kopija v:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Premaknjena izvorna datoteka v:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Ni mogoče izbrisat:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Omogoči samodejno shranjevanje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Samodejno shrani vsakih:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Naloži/Shrani</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Samodejno shrani</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Samodejno shranjevanje v:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Samodejno shranjevanje spodletelo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Samodejno shranjevanje zaključeno.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Najdena je bila samodejno shanjena varnostna kopija neznanege risanja. Jo želite obnovit?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">Najdenih je bil %1 samodejno shanjenih varnostnih kopij neznanih risanj. Jih želite obnovit?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Recover Files?</source>
        <translation>Obnovim datoteke?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnovljeno</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnovim datoteko?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Najdena je bila samodejno shanjena varnostna kopija &apos;%1&apos;. Jo želite obnovit?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Ni mogoče preimenovat:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Premaknjena samodejna kopija v:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Premaknjena izvorna datoteka v:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Ni mogoče izbrisat:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Omogoči samodejno shranjevanje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Samodejno shrani vsakih:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
</context>
</TS>
